@@ -304,16 +304,16 @@ mod gates {
         Mux4,
     }
     impl Gate {
-        fn n_inputs(&self) -> u32 {
-            match *self {
+        fn n_inputs(self) -> u32 {
+            match self {
                 Gate::Not => 1,
                 Gate::And | Gate::Or => 2,
                 Gate::Mux2 => 3,
                 Gate::Mux4 => 6,
             }
         }
-        fn eval(&self, inp: &[bool]) -> bool {
-            match *self {
+        fn eval(self, inp: &[bool]) -> bool {
+            match self {
                 Gate::Not => !inp[0],
                 Gate::And => inp[0] & inp[1],
                 Gate::Or => inp[0] | inp[1],
@@ -379,7 +379,8 @@ mod gates {
         pub fn eval(&self, inp: &[bool]) -> bool {
             let mut outputs = vec![];
             for &(ref gate, ref args) in &self.operations {
-                let gate_inp: Vec<bool> = args.iter()
+                let gate_inp: Vec<bool> = args
+                    .iter()
                     .map(|a| *inp.iter().chain(&outputs).nth(*a as usize).unwrap())
                     .collect();
                 outputs.push(gate.eval(&gate_inp));
